{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "commonworkflowlanguage/cwltool_module",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#merge-metadata.cwl/metadata"
                },
                {
                    "type": "File",
                    "id": "#merge-metadata.cwl/metadataSchema"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#merge-metadata.cwl/subjects"
                }
            ],
            "stdout": "mergedmetadata.ttl",
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "import schema_salad.schema\nimport schema_salad.jsonld_context\n\nmetadataSchema = '$(inputs.metadataSchema.path)'\nmetadata = $(inputs.metadata)\nsubjects = $(inputs.subjects)\n\n(document_loader,\n avsc_names,\n schema_metadata,\n metaschema_loader) = schema_salad.schema.load_schema(metadataSchema)\n\nfor i, m in enumerate(metadata):\n    doc, metadata = schema_salad.schema.load_and_validate(document_loader, avsc_names, m[\"path\"], True)\n    doc[\"id\"] = subjects[i]\n    g = schema_salad.jsonld_context.makerdf(subjects[i], doc, document_loader.ctx)\n    print(g.serialize(format=\"ntriples\").decode(\"utf-8\"))\n",
                            "entryname": "merge-metadata.py"
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                }
            ],
            "baseCommand": [
                "python3",
                "merge-metadata.py"
            ],
            "id": "#merge-metadata.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#merge-metadata.cwl/merged",
                    "outputBinding": {
                        "glob": "mergedmetadata.ttl"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "id": "#minimap2.cwl/readsFA"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#minimap2.cwl/readsPAF",
                    "outputBinding": {
                        "glob": "$(inputs.readsFA.nameroot).paf"
                    }
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/minimap2:2.17--h8b12597_1",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 8,
                    "coresMax": 32,
                    "ramMin": "$(7 * 1024)",
                    "outdirMin": "$(Math.ceil(inputs.readsFA.size/(1024*1024*1024) + 20))",
                    "class": "ResourceRequirement"
                }
            ],
            "stdout": "$(inputs.readsFA.nameroot).paf",
            "baseCommand": "minimap2",
            "arguments": [
                "-cx",
                "asm20",
                "-w",
                "1",
                "-t",
                "$(runtime.cores)",
                "$(inputs.readsFA)",
                "$(inputs.readsFA)"
            ],
            "id": "#minimap2.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "id": "#odgi-build.cwl/inputGFA"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.inputGFA.nameroot).odgi"
                    },
                    "id": "#odgi-build.cwl/odgiGraph"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/odgi:v0.3--py37h8b12597_0",
                    "class": "DockerRequirement"
                },
                {
                    "listing": [
                        {
                            "entry": "$(inputs.inputGFA)",
                            "writable": true
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": "$(7 * 1024)",
                    "outdirMin": "$(Math.ceil((inputs.inputGFA.size/(1024*1024*1024)+1) * 2))",
                    "class": "ResourceRequirement"
                }
            ],
            "arguments": [
                "odgi",
                "build",
                "-g",
                "$(inputs.inputGFA)",
                "-s",
                "-o",
                "-",
                {
                    "shellQuote": false,
                    "valueFrom": "|"
                },
                "odgi",
                "sort",
                "-i",
                "-",
                "-p",
                "s",
                "-o",
                "$(inputs.inputGFA.nameroot).odgi"
            ],
            "id": "#odgi-build.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "File",
                    "id": "#odgi-viz.cwl/inputODGI"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.inputODGI.nameroot).png"
                    },
                    "id": "#odgi-viz.cwl/odgiPNG"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/odgi:v0.3--py37h8b12597_0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": "$(7 * 1024)",
                    "outdirMin": 1,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "odgi",
                "viz"
            ],
            "arguments": [
                "-i",
                "$(inputs.inputODGI)",
                "-o",
                "$(inputs.inputODGI.nameroot).png",
                "-x",
                "50000",
                "-y",
                "500",
                "-R",
                "-P",
                "4"
            ],
            "id": "#odgi-viz.cwl"
        },
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "spodgi/spodgi",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "inputs": [
                {
                    "id": "#odgi_to_rdf.cwl/odgi",
                    "type": "File"
                },
                {
                    "id": "#odgi_to_rdf.cwl/output_name",
                    "type": [
                        "null",
                        "string"
                    ]
                }
            ],
            "stdout": "$(inputs.output_name || inputs.odgi.nameroot+'.ttl.xz')",
            "arguments": [
                "odgi_to_rdf.py",
                "$(inputs.odgi)",
                "-",
                {
                    "valueFrom": "|",
                    "shellQuote": false
                },
                "xz",
                "--stdout"
            ],
            "outputs": [
                {
                    "id": "#odgi_to_rdf.cwl/rdf",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name || inputs.odgi.nameroot+'.ttl.xz')"
                    }
                }
            ],
            "id": "#odgi_to_rdf.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/inputReads"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/metadata"
                },
                {
                    "type": "File",
                    "id": "#main/metadataSchema"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/subjects"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/mergeMetadata/merged",
                    "id": "#main/mergedMetadata"
                },
                {
                    "type": "File",
                    "outputSource": "#main/buildGraph/odgiGraph",
                    "id": "#main/odgiGraph"
                },
                {
                    "type": "File",
                    "outputSource": "#main/vizGraph/odgiPNG",
                    "id": "#main/odgiPNG"
                },
                {
                    "type": "File",
                    "outputSource": "#main/odgi2rdf/rdf",
                    "id": "#main/odgiRDF"
                },
                {
                    "type": "File",
                    "outputSource": "#main/induceGraph/seqwishGFA",
                    "id": "#main/seqwishGFA"
                }
            ],
            "steps": [
                {
                    "in": [
                        {
                            "source": "#main/induceGraph/seqwishGFA",
                            "id": "#main/buildGraph/inputGFA"
                        }
                    ],
                    "out": [
                        "#main/buildGraph/odgiGraph"
                    ],
                    "run": "#odgi-build.cwl",
                    "id": "#main/buildGraph"
                },
                {
                    "in": [
                        {
                            "source": "#main/inputReads",
                            "id": "#main/dedup/readsFA"
                        }
                    ],
                    "out": [
                        "#main/dedup/readsMergeDedup"
                    ],
                    "run": "#seqkit-rmdup.cwl",
                    "id": "#main/dedup"
                },
                {
                    "in": [
                        {
                            "source": "#main/dedup/readsMergeDedup",
                            "id": "#main/induceGraph/readsFA"
                        },
                        {
                            "source": "#main/overlapReads/readsPAF",
                            "id": "#main/induceGraph/readsPAF"
                        }
                    ],
                    "out": [
                        "#main/induceGraph/seqwishGFA"
                    ],
                    "run": "#seqwish.cwl",
                    "id": "#main/induceGraph"
                },
                {
                    "in": [
                        {
                            "source": "#main/metadata",
                            "id": "#main/mergeMetadata/metadata"
                        },
                        {
                            "source": "#main/metadataSchema",
                            "id": "#main/mergeMetadata/metadataSchema"
                        },
                        {
                            "source": "#main/subjects",
                            "id": "#main/mergeMetadata/subjects"
                        }
                    ],
                    "out": [
                        "#main/mergeMetadata/merged"
                    ],
                    "run": "#merge-metadata.cwl",
                    "id": "#main/mergeMetadata"
                },
                {
                    "in": [
                        {
                            "source": "#main/buildGraph/odgiGraph",
                            "id": "#main/odgi2rdf/odgi"
                        }
                    ],
                    "out": [
                        "#main/odgi2rdf/rdf"
                    ],
                    "run": "#odgi_to_rdf.cwl",
                    "id": "#main/odgi2rdf"
                },
                {
                    "in": [
                        {
                            "source": "#main/dedup/readsMergeDedup",
                            "id": "#main/overlapReads/readsFA"
                        }
                    ],
                    "out": [
                        "#main/overlapReads/readsPAF"
                    ],
                    "run": "#minimap2.cwl",
                    "id": "#main/overlapReads"
                },
                {
                    "in": [
                        {
                            "source": "#main/buildGraph/odgiGraph",
                            "id": "#main/vizGraph/inputODGI"
                        }
                    ],
                    "out": [
                        "#main/vizGraph/odgiPNG"
                    ],
                    "run": "#odgi-viz.cwl",
                    "id": "#main/vizGraph"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#seqkit-rmdup.cwl/readsFA"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "readsMergeDedup.fasta"
                    },
                    "id": "#seqkit-rmdup.cwl/readsMergeDedup"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/seqkit:0.7.1--0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 8,
                    "coresMax": 32,
                    "ramMin": "$(7 * 1024)",
                    "outdirMin": "${\n  var sum = 0;\n  for (var i = 0; i < inputs.readsFA.length; i++) {\n    sum += inputs.readsFA[i].size;\n  }\n  return (sum/(1024*1024*1024)+1) + 20;\n}\n",
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": "seqkit",
            "arguments": [
                "rmdup",
                "--by-seq",
                "--ignore-case",
                "-o",
                "readsMergeDedup.fasta",
                "$(inputs.readsFA)"
            ],
            "id": "#seqkit-rmdup.cwl"
        },
        {
            "class": "CommandLineTool",
            "inputs": [
                {
                    "type": "int",
                    "default": 16,
                    "id": "#seqwish.cwl/kmerSize"
                },
                {
                    "type": "File",
                    "id": "#seqwish.cwl/readsFA"
                },
                {
                    "type": "File",
                    "id": "#seqwish.cwl/readsPAF"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.readsPAF.nameroot).gfa"
                    },
                    "id": "#seqwish.cwl/seqwishGFA"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "quay.io/biocontainers/seqwish:0.4.1--h8b12597_0",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": "$(7 * 1024)",
                    "outdirMin": "$(Math.ceil(inputs.readsFA.size/(1024*1024*1024) + 20))",
                    "class": "ResourceRequirement"
                }
            ],
            "stdout": "$(inputs.readsFA.nameroot).paf",
            "baseCommand": "seqwish",
            "arguments": [
                "-t",
                "$(runtime.cores)",
                "-k",
                "$(inputs.kmerSize)",
                "-s",
                "$(inputs.readsFA)",
                "-p",
                "$(inputs.readsPAF)",
                "-g",
                "$(inputs.readsPAF.nameroot).gfa"
            ],
            "id": "#seqwish.cwl"
        }
    ],
    "cwlVersion": "v1.1"
}
